# blockauth-lib-react

This is a LIB-react for the BlockAuth project. It is a React component library that uses the SDK
to interact with the BlockAuth smart contracts and Websocket server.

[![pipeline status](https://gitlab.com/blockauthio/blockauth-lib-react/badges/main/pipeline.svg)](https://gitlab.com/blockauthio/blockauth-lib-react/-/commits/main) [![coverage report](https://gitlab.com/blockauthio/blockauth-lib-react/badges/main/coverage.svg)](https://gitlab.com/blockauthio/blockauth-lib-react/-/commits/main) [![Latest Release](https://gitlab.com/blockauthio/blockauth-lib-react/-/badges/release.svg)](https://gitlab.com/blockauthio/blockauth-lib-react/-/releases)

# How to use?

Use the official documentation at [block-auth.io](https://docs.block-auth.io/) to learn how to use the SDK.

## Development

Install dependencies

```bash
  npm install
```

CI/CD

```bash
  npm run ci
```

Start the development server

```bash
  npm run dev
```

After making changes to the code, run the following command to format the code, run the linter, and start the development server:

```bash
  npm run css && npm run lint && npm run format && npm ci:compile
```

**WARNING** : Don't forget to remove unused css classes from the `public/output.css` file becase tailwind.css generates a lot of unused css classes.

## NPM Scripts

| Script          | Description                                                                                      |
| :-------------- | :----------------------------------------------------------------------------------------------- |
| `dev`           | Starts the development server                                                                    |
| `css`           | Builds the CSS                                                                                   |
| `css:dev`       | Builds the CSS in development mode                                                               |
| `test`          | Runs the tests and generates a coverage report                                                   |
| `lint`          | Runs the linter                                                                                  |
| `lint:fix`      | Runs the linter and fixes the errors                                                             |
| `format`        | Formats the code                                                                                 |
| `build`         | Builds the app for production                                                                    |
| `preview`       | Builds the app for production and previews it locally                                            |
| `ci`            | Runs the tests, linter, and code formatter                                                       |
| `stories`       | Starts the Storybook server                                                                      |
| `stories:build` | Builds the Storybook app for production                                                          |
| `docs`          | Starts the documentation server                                                                  |
| `docs:build`    | Builds the documentation app for production                                                      |
| `clean`         | Removes `dist`, `dist-stories`, `dist-docs`, `package-lock.json`, `.coverage` and `node_modules` |

## Usage/Examples

```javascript
import 'blockauth-lib-react/public/output.css' // Import Tailwind CSS
import {
  BtnArrowDir,
  BtnBase,
  BtnClose,
  BtnSave,
  BtnSubmit,
  DividerBase,
  DropdownFlags,
  AnimatedSlideWrapper,
  EmptyBase,
  WrapperBase,
  ArrowIcon,
  BellIcon,
  CheckmarkIcon,
  LogoBAIcon,
  IconBase,
  Checkbox,
  CheckboxAnimated,
  MessageBase,
  HorizontalLoader,
  OvalSpinner,
  DropdownNotifications,
  NotificationItem,
  NotificationList,
  NotificationSentAt,
  Notifications,
  NotificationsBase,
  Switcher,
  Progressbar,
  SwitcherDarkMode,
  // helpers
  // hooks
  // services
  BrowserBase,
  // stores
  useStoreNotifications,
} from 'blockauth-lib-react'
import { useState } from 'react'

export default function App() {
  const [notifications, setNotifications] = useState([
    {
      id: '1',
      title: 'Notification 1',
      message: 'This is a notification message',
      sentAt: '2021-09-01T00:00:00Z',
    },
    {
      id: '2',
      title: 'Notification 2',
      message: 'This is a notification message',
      sentAt: '2021-09-01T00:00:00Z',
    },
    {
      id: '3',
      title: 'Notification 3',
      message: 'This is a notification message',
      sentAt: '2021-09-01T00:00:00Z',
    },
  ])

  return (
    <div>
      <BtnArrowDir />
      <BtnBase />
      <BtnClose />
      <BtnSave />
      <BtnSubmit />
      <DividerBase />
      <DropdownFlags />
      <AnimatedSlideWrapper />
      <EmptyBase />
      <WrapperBase />
      <ArrowIcon />
      <BellIcon />
      <CheckmarkIcon />
      <LogoBAIcon />
      <IconBase />
      <Checkbox />
      <CheckboxAnimated />
      <MessageBase />
      <HorizontalLoader />
      <OvalSpinner />
      <DropdownNotifications />
      <NotificationItem />
      <NotificationList />
      <NotificationSentAt />
      <Notifications />
      <NotificationsBase />
      <Switcher />
      <Progressbar />
      <SwitcherDarkMode />
      <BrowserBase />
      <NotificationsBase
        notifications={notifications}
        setNotifications={setNotifications}
      />
    </div>
  )
}
```

## Authors

Block-Auth.io Team
